from .api import NRQL
import json
from argparse import ArgumentParser

from pygments import highlight, lexers, formatters


def main():
    parser = ArgumentParser(prog='nrql-simple')
    parser.add_argument('stmt',
                        help="The NRQL statement.")
    parser.add_argument('--verbose', '--v',
                        dest='verbose',
                        action='store_true',
                        default=False,
                        help="Pass this flag if you want the whole response. "
                             "The program only outputs the results array by default.")
    parser.add_argument('region',
                        nargs='?',
                        default='US',
                        help="Pass this flag to set your region (EU or US) By default the region is set to US.")
    args = parser.parse_args()
    nrql = NRQL()
    nrql.region = args.region
    nrql.verbose = args.verbose
    req = nrql.query(args.stmt)
    formatted_json = json.dumps(req, sort_keys=True, indent=4)
    colorful_json = highlight(str(formatted_json).encode('utf-8'), lexers.JsonLexer(), formatters.TerminalFormatter())
    print(colorful_json)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
from shutil import rmtree

from setuptools import setup, Command, find_packages

# Package meta-data.
NAME = 'nrql-simple'
DESCRIPTION = 'nrql-simple is a small Python library that provides a convenient way to interact with the New Relic Insights query API. You can interact with this library programmatically or via the Command Line.'
URL = 'https://github.com/anthonybloomer/nrql-simple'
EMAIL = 'ant0@protonmail.ch'
AUTHOR = 'Anthony Bloomer'
REQUIRES_PYTHON = '>=2.7.10'
VERSION = None
LICENSE = 'MIT'
REQUIRED = [
    'requests', 'pygments'
]

here = os.path.abspath(os.path.dirname(__file__))

with open("README.rst", "rb") as f:
    long_descr = f.read().decode("utf-8")

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, '__version__.py')) as f:
        exec (f.read(), about)
else:
    about['__version__'] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPi via Twine…')
        os.system('twine upload dist/*')

        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(about['__version__']))
        os.system('git push --tags')

        sys.exit()


setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    packages=find_packages(exclude=('tests',)),
    long_description=long_descr,
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    py_modules=['nrql'],
    entry_points={
        'console_scripts': ['nrql = nrql.app:main']
    },
    install_requires=REQUIRED,
    include_package_data=True,
    license=LICENSE,
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        "Topic :: Software Development :: Libraries",
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    cmdclass={
        'upload': UploadCommand,
    },
)



import requests
import os


class NRQL(object):

    def __init__(self, api_key=None, account_id=None):
        self._api_key = api_key
        self._account_id = account_id
        self._url = "https://insights-api.newrelic.com/v1/accounts/%s/query?nrql=%s"
        self._eu_url = "https://insights-api.eu.newrelic.com/v1/accounts/%s/query?nrql=%s"
        self._region = 'US'
        self._verbose = False
        self._environment = None

    @property
    def api_key(self):
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        self._api_key = api_key

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        self._account_id = account_id

    @property
    def region(self):
        return self._region

    @region.setter
    def region(self, region):
        self._region = region

    @property
    def verbose(self):
        return self._verbose

    @verbose.setter
    def verbose(self, verbose):
        self._verbose = verbose

    @property
    def environment(self):
        return self._environment

    @environment.setter
    def environment(self, environment):
        self._environment = environment

    def query(self, stmt):

        if not self.api_key or not self.account_id:
            if os.environ.get('NR_API_KEY') and os.environ.get('NR_ACCOUNT_ID'):
                self._api_key = os.environ.get('NR_API_KEY')
                self._account_id = os.environ.get('NR_ACCOUNT_ID')
            else:
                raise Exception("An api key and account id is required.")

        if not self.region == 'US':
            self._url = self._eu_url

        req = requests.get(self._url % (self.account_id, stmt), headers={"X-Query-Key": self.api_key})

        response = req.json()

        if not self.verbose:
            response.pop('metadata', None)
            response.pop('performanceStats', None)

        return response
